'''
Information about this python-fedora release
'''


NAME = 'python-fedora'
VERSION = '1.0.0'
DESCRIPTION = 'Python modules for interacting with Fedora Services'
LONG_DESCRIPTION = '''
The Fedora Project runs many different services.  These services help us to
package software, develop new programs, and generally put together the distro.
This package contains software that helps us do that.
'''
AUTHOR = 'Toshio Kuratomi, Luke Macken, Ricky Elrod, Ralph Bean, Patrick Uiterwijk'
EMAIL = 'admin@fedoraproject.org'
COPYRIGHT = '2007-2020 Red Hat, Inc.'
URL = 'https://github.com/fedora-infra/python-fedora'
DOWNLOAD_URL = 'https://pypi.python.org/pypi/python-fedora'
LICENSE = 'LGPLv2+'
